Container

Enum Container 

pub enum Container<'e, 'a: 'e> {
    Array(Array<'e, 'a>),
    Struct(Vec<Param<'a, 'e>>),
    Dict(Dict<'a, 'e>),
    Variant(Box<Variant<'a, 'e>>),
    ArrayRef(ArrayRef<'a, 'e>),
    StructRef(&'a [Param<'a, 'e>]),
    DictRef(DictRef<'a, 'e>),
}
The container types a message can have as parameters

’a is the lifetime of the Container, ’e the liftime of the params which may be longer

Variants



Array(Array<'e, 'a>)



Struct(Vec<Param<'a, 'e>>)



Dict(Dict<'a, 'e>)



Variant(Box<Variant<'a, 'e>>)



ArrayRef(ArrayRef<'a, 'e>)



StructRef(&'a [Param<'a, 'e>])



DictRef(DictRef<'a, 'e>)

Implementations

Source

impl<'e, 'a: 'e> Container<'a, 'e>

pub fn push<P: Into<Param<'a, 'e>>>( &mut self, new: P, ) -> Result<(), MarshalError>

pub fn insert<K: Into<Base<'a>>, V: Into<Param<'a, 'e>>>( &mut self, key: K, val: V, ) -> Result<(), MarshalError>

Source

impl<'e, 'a: 'e> Container<'a, 'e>

pub fn make_struct<P: Into<Param<'a, 'e>>>( elements: Vec<P>, ) -> Container<'a, 'e>

pub fn make_struct_ref(elements: &'a [Param<'a, 'e>]) -> Container<'a, 'e>

pub fn make_struct1<P: Into<Param<'a, 'e>>>(e1: P) -> Container<'a, 'e>

pub fn make_struct2<P1: Into<Param<'a, 'e>>, P2: Into<Param<'a, 'e>>>( e1: P1, e2: P2, ) -> Container<'a, 'e>

pub fn make_struct3<P1: Into<Param<'a, 'e>>, P2: Into<Param<'a, 'e>>, P3: Into<Param<'a, 'e>>>( e1: P1, e2: P2, e3: P3, ) -> Container<'a, 'e>

pub fn make_variant<P: Into<Param<'a, 'e>>>(element: P) -> Container<'a, 'e>

pub fn make_array_ref( element_sig: &str, elements: &'a [Param<'a, 'e>], ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_array_ref_with_sig( element_sig: Type, elements: &'a [Param<'a, 'e>], ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_array<P: Into<Param<'a, 'e>>, I: Iterator<Item = P>>( element_sig: &str, elements: I, ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_array_with_sig<P: Into<Param<'a, 'e>>, I: Iterator<Item = P>>( element_sig: Type, elements: I, ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_dict<K: Into<Base<'e>>, V: Into<Param<'a, 'e>>, I: Iterator<Item = (K, V)>>( key_sig: &str, val_sig: &str, map: I, ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_dict_with_sig<K: Into<Base<'e>>, V: Into<Param<'a, 'e>>, I: Iterator<Item = (K, V)>>( key_sig: Base, value_sig: Type, map: I, ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_dict_ref( key_sig: &str, val_sig: &str, map: &'a DictMap<'_, '_>, ) -> Result<Container<'a, 'e>, MarshalError>

pub fn make_dict_ref_with_sig( key_sig: Base, value_sig: Type, map: &'a DictMap<'_, '_>, ) -> Result<Container<'a, 'e>, MarshalError>

Source

impl<'a, 'e> Container<'a, 'e>

pub fn make_signature(&self, buf: &mut String)

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn sig(&self) -> Type