Param

Enum Param 

pub enum Param<'a, 'e> {
    Base(Base<'a>),
    Container(Container<'a, 'e>),
}
The Types a message can have as parameters There are From impls for most of the Base ones

’a is the lifetime of the Container, ’e the liftime of the params which may be longer

Variants



Base(Base<'a>)



Container(Container<'a, 'e>)

Implementations

Source

impl<'a, 'e> Param<'a, 'e>

pub fn into_container(self) -> Result<Container<'a, 'e>, Param<'a, 'e>>

pub fn as_base(&'a self) -> Option<&'a Base<'a>>

pub fn as_base_mut(&'a mut self) -> Option<&'a mut Base<'a>>

pub fn as_slice(&'a self) -> Option<&'a [Param<'_, '_>]>

pub fn as_str(&'a self) -> Option<&'a str>

pub fn as_u64(&'a self) -> Option<&'a u64>

pub fn as_u32(&'a self) -> Option<&'a u32>

pub fn as_u16(&'a self) -> Option<&'a u16>

pub fn as_i64(&'a self) -> Option<&'a i64>

pub fn as_i32(&'a self) -> Option<&'a i32>

pub fn as_i16(&'a self) -> Option<&'a i16>

pub fn as_byte(&'a self) -> Option<&'a u8>

pub fn as_bool(&'a self) -> Option<&'a bool>

pub fn as_unix_fd(&'a self) -> Option<&'a UnixFd>

pub fn into_string(self) -> Result<String, Param<'a, 'e>>

pub fn into_str(self) -> Result<&'a str, Param<'a, 'e>>

pub fn into_u64(self) -> Result<u64, Param<'a, 'e>>

pub fn into_u32(self) -> Result<u32, Param<'a, 'e>>

pub fn into_u16(self) -> Result<u16, Param<'a, 'e>>

pub fn into_i64(self) -> Result<i64, Param<'a, 'e>>

pub fn into_i32(self) -> Result<i32, Param<'a, 'e>>

pub fn into_i16(self) -> Result<i16, Param<'a, 'e>>

pub fn into_byte(self) -> Result<u8, Param<'a, 'e>>

pub fn into_bool(self) -> Result<bool, Param<'a, 'e>>

Source

impl<'a, 'e> Param<'a, 'e>

pub fn make_signature(&self, buf: &mut String)

pub fn sig(&self) -> Type